/**
 * @file modules/generated/module_console_generated.h
 * @brief Definition of module_console written in array. Generated by json_to_array.py
 * @copyright (c) 2021 Avast Software, licensed under the MIT license
 */
 #pragma once

 #include "yaramod/types/modules/module_content.h"

 namespace yaramod {

 namespace modules {

 class Gmodule_console : public ModuleContent
 {
 public:
    static constexpr std::size_t module_content_size = 1892;
    static constexpr const char* module_content_parts[] = {
"{\"kind\": \"struct\", \"name\": \"console\", \"attributes\": [{\"kind\": \"function\", \"name\": \"log\", \"return_type\": \"i\", \"overloads\": [{\"arguments\": [{\"type\": \"s\", \"name\": \"string\"}], \"documentation\": \"Function which sends the string to the main callback.\\n\\nExample: ```console.log(pe.imphash())```\"}, {\"arguments\": [{\"type\": \"s\", \"name\": \"message\"}, {\"type\": \"s\", \"name\": \"string\"}], \"documentation\": \"Function which sends the message and string to the main callback.\\n\\nExample: ```console.log(\\\"The imphash is: \\\", pe.imphash())```\"}, {\"arguments\": [{\"type\": \"i\", \"name\": \"integer\"}], \"documentation\": \"Function which sends the integer to the main callback.\\n\\nExample: ```console.log(uint32(0))```\"}, {\"arguments\": [{\"type\": \"s\", \"name\": \"message\"}, {\"type\": \"i\", \"name\": \"integer\"}], \"documentation\": \"Function which sends the message and integer to the main callback.\\n\\nExample: ```console.log(\\\"32bits at 0: \\\", uint32(0))```\"}, {\"arguments\": [{\"type\": \"f\", \"name\": \"float\"}], \"documentation\": \"Function which sends the floatin",
"g point value to the main callback.\\n\\nExample: ```console.log(math.entropy(0, filesize))```\"}, {\"arguments\": [{\"type\": \"s\", \"name\": \"message\"}, {\"type\": \"f\", \"name\": \"float\"}], \"documentation\": \"Function which sends the message and the floating point value to the main callback.\\n\\nExample: ```console.log(\\\"Entropy: \\\", math.entropy(0, filesize))```\"}]}, {\"kind\": \"function\", \"name\": \"hex\", \"return_type\": \"i\", \"overloads\": [{\"arguments\": [{\"type\": \"i\", \"name\": \"integer\"}], \"documentation\": \"Function which sends the integer to the main callback, formatted as a hex string.\\n\\nExample: ```console.hex(uint32(0))```\"}, {\"arguments\": [{\"type\": \"s\", \"name\": \"message\"}, {\"type\": \"i\", \"name\": \"integer\"}], \"documentation\": \"Function which sends the integer to the main callback, formatted as a hex string.\\n\\nExample: ```console.hex(\\\"Hex at 0: \\\", uint32(0))```\"}]}]}"
    };

    Gmodule_console() : ModuleContent("console")
    {
        std::string content;
        content.reserve(module_content_size);
        for (std::size_t i = 0; i < 2; ++i)
            content += module_content_parts[i];
        setContent(std::move(content));
    }
 };

 } // namespace modules

 } // namespace yaramod
